@@ -174,8 +174,9 @@ class NSGA3:
             lowerbound = tf.constant(lowerbound, dtype = tf.float64)
         else:
             raise TypeError
-        # Check that all upperbound > lowerbound
-        assert tf.reduce_all(upperbound>lowerbound)
+        # Check that all upperbound >= lowerbound
+        # Permits upper==lower to allow some values to be fixed
+        assert tf.reduce_all(upperbound>=lowerbound)
 
         def set_reference_partitions(n_objectives, population_size, partitions=1):
             # Calculate number of reference points for given partitions
@@ -692,8 +693,9 @@ class muPlusLambda:
             lowerbound = tf.constant(lowerbound, dtype = tf.float64)
         else:
             raise TypeError
-        # Check that all upperbound > lowerbound
-        assert tf.reduce_all(upperbound>lowerbound)
+        # Check that all upperbound >= lowerbound
+        # Permits upper==lower to allow some values to be fixed
+        assert tf.reduce_all(upperbound>=lowerbound)
         
         self.generations = generations
         self.population_size = tf.constant(population_size, dtype=tf.int32)
@@ -1003,8 +1005,9 @@ class PSO:
             lowerbound = tf.constant(lowerbound, dtype = tf.float64)
         else:
             raise TypeError
-        # Check that all upperbound > lowerbound
-        assert tf.reduce_all(upperbound>lowerbound)
+        # Check that all upperbound >= lowerbound
+        # Permits upper==lower to allow some values to be fixed
+        assert tf.reduce_all(upperbound>=lowerbound)
         
         self.generations = generations
         self.population_size = tf.constant(population_size, dtype=tf.int32)
